==> google-cloud-sdk-418.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/googlecloudsdk/generated_clients/gapic_clients/storage_v2/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .storage import (
    Bucket,
    BucketAccessControl,
    CancelResumableWriteRequest,
    CancelResumableWriteResponse,
    ChecksummedData,
    CommonObjectRequestParams,
    ComposeObjectRequest,
    ContentRange,
    CreateBucketRequest,
    CreateHmacKeyRequest,
    CreateHmacKeyResponse,
    CreateNotificationRequest,
    CustomerEncryption,
    DeleteBucketRequest,
    DeleteHmacKeyRequest,
    DeleteNotificationRequest,
    DeleteObjectRequest,
    GetBucketRequest,
    GetHmacKeyRequest,
    GetNotificationRequest,
    GetObjectRequest,
    GetServiceAccountRequest,
    HmacKeyMetadata,
    ListBucketsRequest,
    ListBucketsResponse,
    ListHmacKeysRequest,
    ListHmacKeysResponse,
    ListNotificationsRequest,
    ListNotificationsResponse,
    ListObjectsRequest,
    ListObjectsResponse,
    LockBucketRetentionPolicyRequest,
    Notification,
    Object,
    ObjectAccessControl,
    ObjectChecksums,
    Owner,
    ProjectTeam,
    QueryWriteStatusRequest,
    QueryWriteStatusResponse,
    ReadObjectRequest,
    ReadObjectResponse,
    RewriteObjectRequest,
    RewriteResponse,
    ServiceAccount,
    ServiceConstants,
    StartResumableWriteRequest,
    StartResumableWriteResponse,
    UpdateBucketRequest,
    UpdateHmacKeyRequest,
    UpdateObjectRequest,
    WriteObjectRequest,
    WriteObjectResponse,
    WriteObjectSpec,
)

__all__ = (
    'Bucket',
    'BucketAccessControl',
    'CancelResumableWriteRequest',
    'CancelResumableWriteResponse',
    'ChecksummedData',
    'CommonObjectRequestParams',
    'ComposeObjectRequest',
    'ContentRange',
    'CreateBucketRequest',
    'CreateHmacKeyRequest',
    'CreateHmacKeyResponse',
    'CreateNotificationRequest',
    'CustomerEncryption',
    'DeleteBucketRequest',
    'DeleteHmacKeyRequest',
    'DeleteNotificationRequest',
    'DeleteObjectRequest',
    'GetBucketRequest',
    'GetHmacKeyRequest',
    'GetNotificationRequest',
    'GetObjectRequest',
    'GetServiceAccountRequest',
    'HmacKeyMetadata',
    'ListBucketsRequest',
    'ListBucketsResponse',
    'ListHmacKeysRequest',
    'ListHmacKeysResponse',
    'ListNotificationsRequest',
    'ListNotificationsResponse',
    'ListObjectsRequest',
    'ListObjectsResponse',
    'LockBucketRetentionPolicyRequest',
    'Notification',
    'Object',
    'ObjectAccessControl',
    'ObjectChecksums',
    'Owner',
    'ProjectTeam',
    'QueryWriteStatusRequest',
    'QueryWriteStatusResponse',
    'ReadObjectRequest',
    'ReadObjectResponse',
    'RewriteObjectRequest',
    'RewriteResponse',
    'ServiceAccount',
    'ServiceConstants',
    'StartResumableWriteRequest',
    'StartResumableWriteResponse',
    'UpdateBucketRequest',
    'UpdateHmacKeyRequest',
    'UpdateObjectRequest',
    'WriteObjectRequest',
    'WriteObjectResponse',
    'WriteObjectSpec',
)

==> google-cloud-sdk-505.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/googlecloudsdk/generated_clients/gapic_clients/storage_v2/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .storage import (
    BidiWriteObjectRequest,
    BidiWriteObjectResponse,
    Bucket,
    BucketAccessControl,
    CancelResumableWriteRequest,
    CancelResumableWriteResponse,
    ChecksummedData,
    CommonObjectRequestParams,
    ComposeObjectRequest,
    ContentRange,
    CreateBucketRequest,
    CustomerEncryption,
    DeleteBucketRequest,
    DeleteObjectRequest,
    GetBucketRequest,
    GetObjectRequest,
    ListBucketsRequest,
    ListBucketsResponse,
    ListObjectsRequest,
    ListObjectsResponse,
    LockBucketRetentionPolicyRequest,
    MoveObjectRequest,
    Object,
    ObjectAccessControl,
    ObjectChecksums,
    Owner,
    ProjectTeam,
    QueryWriteStatusRequest,
    QueryWriteStatusResponse,
    ReadObjectRequest,
    ReadObjectResponse,
    RestoreObjectRequest,
    RewriteObjectRequest,
    RewriteResponse,
    ServiceConstants,
    StartResumableWriteRequest,
    StartResumableWriteResponse,
    UpdateBucketRequest,
    UpdateObjectRequest,
    WriteObjectRequest,
    WriteObjectResponse,
    WriteObjectSpec,
)

__all__ = (
    'BidiWriteObjectRequest',
    'BidiWriteObjectResponse',
    'Bucket',
    'BucketAccessControl',
    'CancelResumableWriteRequest',
    'CancelResumableWriteResponse',
    'ChecksummedData',
    'CommonObjectRequestParams',
    'ComposeObjectRequest',
    'ContentRange',
    'CreateBucketRequest',
    'CustomerEncryption',
    'DeleteBucketRequest',
    'DeleteObjectRequest',
    'GetBucketRequest',
    'GetObjectRequest',
    'ListBucketsRequest',
    'ListBucketsResponse',
    'ListObjectsRequest',
    'ListObjectsResponse',
    'LockBucketRetentionPolicyRequest',
    'MoveObjectRequest',
    'Object',
    'ObjectAccessControl',
    'ObjectChecksums',
    'Owner',
    'ProjectTeam',
    'QueryWriteStatusRequest',
    'QueryWriteStatusResponse',
    'ReadObjectRequest',
    'ReadObjectResponse',
    'RestoreObjectRequest',
    'RewriteObjectRequest',
    'RewriteResponse',
    'ServiceConstants',
    'StartResumableWriteRequest',
    'StartResumableWriteResponse',
    'UpdateBucketRequest',
    'UpdateObjectRequest',
    'WriteObjectRequest',
    'WriteObjectResponse',
    'WriteObjectSpec',
)
